import ac from 'argument-contracts';
import { convertEventsToEventStreamEvents } from '..';
export class EventsApiClient {
    constructor(_client) {
        this._client = _client;
    }
    getEventsForCrashId(database, crashId) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (crashId <= 0) {
            throw new Error(`Expected crashId to be a positive non-zero number. Value received: "${crashId}"`);
        }
        return this.getEvents(`/api/events?database=${database}&crashId=${crashId}`);
    }
    getEventsForStackKeyId(database, stackKeyId) {
        ac.assertNonWhiteSpaceString(database, 'database');
        if (stackKeyId <= 0) {
            throw new Error(`Expected crashId to be a positive non-zero number. Value received: "${stackKeyId}"`);
        }
        return this.getEvents(`/api/events?database=${database}&stackKeyId=${stackKeyId}`);
    }
    async getEvents(route) {
        const response = await this._client.fetch(route);
        const json = await response.json();
        if (response.status !== 200) {
            throw new Error(json.message);
        }
        return convertEventsToEventStreamEvents(json.events);
    }
}
//# sourceMappingURL=events-api-client.js.map